import { Component, MapChildrenProps } from '../common';
interface ArcData {
    from: {
        city?: string;
        name?: string;
        point?: BMapGL.Point;
    };
    to: {
        city?: string;
        name?: string;
        point?: BMapGL.Point;
    };
    color?: string;
}
interface ArcProps extends MapChildrenProps {
    /** 起点、终点的坐标或城市名数据 */
    data: ArcData[];
    /** 开启动画效果 */
    enableAnimation?: boolean;
    /** 是否显示起点标注 */
    showStartPoint?: boolean;
    /** 是否显示终点标注 */
    showEndPoint?: boolean;
    /** 坐标体系，可选百度经纬度坐标或百度墨卡托坐标 */
    coordType?: 'bd09ll' | 'bd09mc';
    /** 自动聚焦视野 */
    autoViewport?: boolean;
    /** `autoViewport`打开时生效，配置视野的参数 */
    viewportOptions?: BMapGL.ViewportOptions;
    /** 线的样式配置，详情参考 [MapVGL线图层文档](https://mapv.baidu.com/gl/docs/LineLayer.html) */
    lineOptions?: MapVGL.LayerOptions;
    /** 箭头的样式配置，详情参考 [MapVGL线图层文档](https://mapv.baidu.com/gl/docs/LineLayer.html) */
    arrowOptions?: MapVGL.LayerOptions;
    /** 动画的样式配置，详情参考 [MapVGL线图层文档](https://mapv.baidu.com/gl/docs/LineLayer.html) */
    animationOptions?: MapVGL.LayerOptions;
    /** 起终点的样式配置，详情参考 [MapVGL点图层文档](https://mapv.baidu.com/gl/docs/PointLayer.html) */
    pointOptions?: MapVGL.LayerOptions;
    /** 文字的样式配置，详情参考 [MapVGL文字图层文档](https://mapv.baidu.com/gl/docs/TextLayer.html) */
    textOptions?: MapVGL.LayerOptions;
}
/**
 * 根据起终点地名或者坐标，自动生成2D弧线，可用于OD等场景的效果展示
 * @visibleName Arc 2D弧线
 */
export default class Arc extends Component<ArcProps> {
    private _createLayer;
    view: MapVGL.View;
    linelayer: MapVGL.Layer;
    arrowlayer: MapVGL.Layer;
    colorarrowlayers: MapVGL.Layer[];
    flowlayer: MapVGL.Layer;
    pointlayer: MapVGL.Layer;
    textlayer: MapVGL.Layer;
    static defaultProps: ArcProps | object;
    constructor(props: ArcProps);
    componentDidMount(): void;
    componentDidUpdate(prevProps: ArcProps): void;
    componentWillUnmount(): void;
    destroy(): void;
    initialize(): void;
    createLayers(): void;
    render(): null;
}
export {};
