/**
 * @file mapvgl可视化图层
 * @author hedongran
 * @email hdr01@126.com
 */
/// <reference types="react" />
import { Component, MapChildrenProps } from '../common';
import { MapVGLViewChildrenProps } from './MapvglView';
interface MapvglLayerProps extends MapChildrenProps, MapVGLViewChildrenProps {
    /** 绘制图层的构造函数名称，注意`区分大小写` */
    type: string;
    /** 绘制图层的参数，详情参考MapVGL各图层的文档 */
    options: MapVGL.LayerOptions;
    /** MapVGL绘制使用的GeoJSON数据 */
    data: MapVGL.GeoJSON[];
    /** 坐标体系，可选百度经纬度坐标或百度墨卡托坐标 */
    coordType?: 'bd09ll' | 'bd09mc';
    /** 自动聚焦视野 */
    autoViewport?: boolean;
    /** `autoViewport`打开时生效，配置视野的参数 */
    viewportOptions?: BMapGL.ViewportOptions;
    /** 获取内部方法 */
    getMethods?: Function;
}
/**
 * 该组件将MapVGL的图层使用`react`进行了一层封装。具体关于MapVGL有哪些图层，以及图层的属性，请查阅[MapVGL文档](https://mapv.baidu.com/gl/docs/)
 * @visibleName MapvglLayer MapVGL图层
 */
export default class MapvglLayer extends Component<MapvglLayerProps> {
    private _createLayer;
    static contextType: import("react").Context<import("./MapvglView").ViewContextProps>;
    view: MapVGL.View;
    layer: MapVGL.Layer;
    constructor(props: MapvglLayerProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: MapvglLayerProps): void;
    destroy(): void;
    initialize(): void;
    setViewport(): void;
    createLayers(): void;
    render(): null;
}
export {};
