/**
 * @file 地图测距工具库
 * @author hedongran
 * @email hdr01@126.com
 */
/// <reference types="react" />
import { Component, MapChildrenProps } from '../common';
import { Options } from '../common/WrapperHOC';
export interface DistanceToolProps extends BMapGL.DistanceToolOptions, MapChildrenProps {
    /** 默认是否开启测距模式 */
    defaultOpen?: boolean;
    /** 测距过程中，提示框文字 */
    followText?: string;
    /** 测距结果所用的单位制，可接受的属性为`metric`表示米制和`us`表示美国传统单位 */
    unit?: 'metric' | 'us';
    /** 折线颜色 */
    lineColor?: string;
    /** 折线线宽 */
    lineStroke?: number;
    /** 折线透明度 */
    opacity?: number;
    /** 折线样式 */
    lineStyle?: 'solid' | 'dashed' | 'dotted';
    /** 脚本的url地址，默认为在线地址 */
    scriptUrl?: string;
    /** 测距时，每次双击底图结束当前测距折线时，派发事件的接口 */
    onDrawend?(e: Event, info: object): void;
    /** 测距过程中，每次点击底图添加节点时，派发事件的接口 */
    onAddpoint?(e: Event, info: object): void;
    /** 测距结束后，点击线段上最后一个节点旁的关闭按钮时，派发事件的接口 */
    onRemovepolyline?(e: Event, info: object): void;
}
declare class DistanceTool extends Component<DistanceToolProps> {
    static contextType: import("react").Context<import("../Map/Map").MapContextProps>;
    static defaultProps: DistanceToolProps | object;
    distancetool: BMapGLLib.DistanceTool;
    options: Options;
    constructor(props: DistanceToolProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    destroy(): void;
    initialize(): void;
    render(): null;
}
declare const _default: typeof DistanceTool;
/**
 * 用来在地图上测量地理距离，单击添加拐点，双击结束测量。该组件属于不属于原生JSAPI，属于开源工具库[BMapGLLib](https://github.com/huiyan-fe/BMapGLLib)
 * @visibleName DistanceTool 地图测距工具
 */
export default _default;
