/**
 * @file 圆形覆盖物
 * @author hedongran
 * @email hdr01@126.com
 */
import Graphy, { GraphyProps } from './Graphy';
interface CircleProps extends GraphyProps {
    /** 圆形的坐标数组 */
    center: BMapGL.Point;
    /** 圆形的半径，单位为米 */
    radius: number;
    /** 描边的颜色，同CSS颜色 */
    strokeColor?: string;
    /** 描边的宽度，单位为像素 */
    strokeWeight?: number;
    /** 描边的透明度，范围`0-1` */
    strokeOpacity?: number;
    /** 描边的样式，为实线、虚线、或者点状线 */
    strokeStyle?: 'solid' | 'dashed' | 'dotted';
    /** 面填充颜色，同CSS颜色 */
    fillColor?: string;
    /** 面填充的透明度，范围`0-1` */
    fillOpacity?: number;
    /** 可通过`map.clearOverlays()`方法移除 */
    enableMassClear?: boolean;
    /** 开启可编辑模式 */
    enableEditing?: boolean;
}
/**
 * 在地图上绘制简单的圆形
 * @visibleName Circle 圆形
 */
export default class Circle extends Graphy<CircleProps> {
    overlay: BMapGL.Circle;
    options: string[];
    constructor(props: CircleProps);
    onDataUpdate(prevProps: CircleProps): void;
    getOverlay(): BMapGL.Circle;
    parseCenter(center: BMapGL.Point): BMapGL.Point;
    render(): null;
}
export {};
