/**
 * @file 信息窗口
 * @author hedongran
 * @email hdr01@126.com
 */
/// <reference types="react" />
import { Component, MapChildrenProps } from '../common';
import { Options } from '../common/WrapperHOC';
export interface InfoWindowProps extends MapChildrenProps {
    /** 坐标体系，可选百度经纬度坐标或百度墨卡托坐标 */
    coordType?: 'bd09ll' | 'bd09mc';
    /** 信息窗口的坐标 */
    position: BMapGL.Point;
    /** 设置信息窗口的标题 */
    title?: string;
    /** 快速设置信息窗口的内容文本 */
    text?: string;
    /** 信息窗口的像素偏移 */
    offset?: BMapGL.Size;
    /** 是否在调用`Map.clearOverlays()`时清除此覆盖物 */
    enableMassClear?: boolean;
    /** 信息窗口宽度 */
    width?: number;
    /** 信息窗口高度 */
    height?: number;
    /** 信息窗口关闭事件的回调函数 */
    onClose?(e: Event): void;
    /** 信息窗口开启事件的回调函数 */
    onOpen?(e: Event): void;
    /** 鼠标点击信息窗口关闭按钮事件的回调函数 */
    onClickclose?(e: Event): void;
}
declare class InfoWindow extends Component<InfoWindowProps> {
    static contextType: import("react").Context<import("../Map/Map").MapContextProps>;
    static defaultProps: InfoWindowProps | object;
    infoWindow: BMapGL.InfoWindow;
    content?: HTMLDivElement;
    options: Options;
    constructor(props: InfoWindowProps);
    componentDidUpdate(prevProps: InfoWindowProps): void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    destroy(): void;
    initialize(): void;
    parsePosition(position: BMapGL.Point): BMapGL.Point;
    render(): null;
}
declare const _default: typeof InfoWindow;
/**
 * 在地图上创建信息窗口，用于展示弹窗信息
 * @visibleName InfoWindow 信息窗口
 */
export default _default;
