/**
 * @file 折线覆盖物
 * @author hedongran
 * @email hdr01@126.com
 */
import Graphy, { GraphyProps } from './Graphy';
interface PolylineProps extends Omit<Omit<GraphyProps, 'fillColor'>, 'fillOpacity'> {
    /** 折线的坐标数组 */
    path: BMapGL.Point[];
    /** 折线的颜色，同CSS颜色 */
    strokeColor?: string;
    /** 折线的宽度，单位为像素 */
    strokeWeight?: number;
    /** 线的透明度，范围`0-1` */
    strokeOpacity?: number;
    /** 设置线为实线、虚线、或者点状线 */
    strokeStyle?: 'solid' | 'dashed' | 'dotted';
    /** 可通过`map.clearOverlays()`方法移除 */
    enableMassClear?: boolean;
    /** 开启可编辑模式 */
    enableEditing?: boolean;
}
/**
 * 在地图上绘制简单的折线
 * @visibleName Polyline 折线
 */
export default class Polyline extends Graphy<PolylineProps> {
    overlay: BMapGL.Polyline;
    options: string[];
    constructor(props: PolylineProps);
    onDataUpdate(prevProps: PolylineProps): void;
    getOverlay(): BMapGL.Polyline;
    parsePath(path: BMapGL.Point[]): BMapGL.Point[];
    render(): null;
}
export {};
